@@ -430,7 +430,7 @@ GSwitchItXkbConfigInit (GSwitchItXkbConfig * xkbConfig,
 			      GSWITCHIT_CONFIG_XKB_DIR,
 			      GCONF_CLIENT_PRELOAD_NONE, &gerror);
 	if (gerror != NULL) {
-		g_error ("err: %s\n", gerror->message);
+		g_warning ("err: %s\n", gerror->message);
 		g_error_free (gerror);
 		gerror = NULL;
 	}
@@ -814,7 +814,7 @@ GSwitchItAppletConfigInit (GSwitchItAppletConfig * appletConfig,
 			      GSWITCHIT_CONFIG_APPLET_DIR,
 			      GCONF_CLIENT_PRELOAD_NONE, &gerror);
 	if (gerror != NULL) {
-		g_error ("err1:%s\n", gerror->message);
+		g_warning ("err1:%s\n", gerror->message);
 		g_error_free (gerror);
 		gerror = NULL;
 	}
